@@ -24,6 +24,7 @@
 #include "protocols/aiwaprotocol.h"
 #include "protocols/lircprotocol.h"
 #include "protocols/necprotocol.h"
+#include <QComboBox>
 
 AiwaVCR1::AiwaVCR1(
   unsigned int index)
@@ -293,8 +294,7 @@ void AiwaAudio1::populateProtocol(
 
   addKey("volume_up", VolumeUp_Key, 0x11, 8);
   addKey("volume_down", VolumeDown_Key, 0x12, 8);
-  addKey("tuner_band", AM_Key, 0x13, 8);  // This is a hack
-  addKey("tuner_band", FM_Key, 0x13, 8);  // This too
+  addKey("tuner_band", ToggleBand_Key, 0x13, 8);
   addKey("tape_play", Unmapped_Key, 0x14, 8);
   addKey("tape_stop", Unmapped_Key, 0x15, 8);
   addKey("tape_next", Unmapped_Key, 0x16, 8);
@@ -341,6 +341,18 @@ void AiwaAudio1::populateProtocol(
 }
 
 
+void AiwaAudio1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("Tape", QVariant(TapeInput_Key));
+  cb->addItem("Tuner", QVariant(TunerInput_Key));
+  cb->addItem("CD", QVariant(CDInput_Key));
+  cb->addItem("Aux", QVariant(AuxInput_Key));
+}
+
+
 AiwaAudio1a::AiwaAudio1a(
   unsigned int index)
   : AiwaAudio1(index)
@@ -477,6 +489,21 @@ void AiwaAudio2::populateProtocol(
 }
 
 
+void AiwaAudio2::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("Tape", QVariant(TapeInput_Key));
+  cb->addItem("Video", QVariant(AuxInput_Key));
+  cb->addItem("CD", QVariant(CDInput_Key));
+  cb->addItem("CD Disc 1", QVariant(DiscOne_Key));
+  cb->addItem("CD Disc 2", QVariant(DiscTwo_Key));
+  cb->addItem("CD Disc 3", QVariant(DiscThree_Key));
+  cb->addItem("MD", QVariant(MDInput_Key));
+}
+
+
 AiwaAudio2a::AiwaAudio2a(
   unsigned int index)
   : AiwaAudio2(index)
@@ -775,6 +802,17 @@ void AiwaAudio6::populateProtocol(
 }
 
 
+void AiwaAudio6::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("VCR / Aux", QVariant(AuxInput_Key));
+  cb->addItem("Phono", QVariant(PhonoInput_Key));
+  cb->addItem("Tape", QVariant(TapeInput_Key));
+}
+
+
 AiwaCarStereo1::AiwaCarStereo1(
   unsigned int index)
   : PIRKeysetMetaData(
@@ -803,7 +841,8 @@ void AiwaCarStereo1::populateProtocol(
   addKey("vol-", VolumeDown_Key, 0x10, 8);
   addKey("disc_tune+", ChannelUp_Key, 0x11, 8);
   addKey("disc_tune-", ChannelDown_Key, 0x12, 8);
-  addKey("radio_band", TunerInput_Key, 0x13, 8);
+  addKey("radio_band", ToggleBand_Key, 0x13, 8);
+  addKey("radio_band", TunerInput_Key, 0x13, 8); // ?
   addKey("tape", TapeInput_Key, 0x14, 8);
   addKey("ff_next", FastForward_Key, 0x16, 8);
   addKey("rew_prev", Rewind_Key, 0x17, 8);
@@ -813,6 +852,16 @@ void AiwaCarStereo1::populateProtocol(
 }
 
 
+void AiwaCarStereo1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("Radio", QVariant(TunerInput_Key));
+  cb->addItem("Tape", QVariant(TapeInput_Key));
+}
+
+
 AiwaDVD1::AiwaDVD1(
   unsigned int index)
   : PIRKeysetMetaData(
