@@ -24,6 +24,7 @@
 #include "protocols/necprotocol.h"
 #include "protocols/necxprotocol.h"
 #include "protocols/rc5protocol.h"
+#include <QComboBox>
 
 
 CambridgeCD1::CambridgeCD1(
@@ -189,9 +190,9 @@ void CambridgeAudio2::populateProtocol(
   addKey("ENTER", Select_Key, 0x21, 8);
 
   addKey("DVD", DVDInput_Key, 0x22, 8);
-  addKey("VIDEO1", Unmapped_Key, 0x23, 8);
-  addKey("VIDEO2", Unmapped_Key, 0x24, 8);
-  addKey("VIDEO3", Unmapped_Key, 0x25, 8);
+  addKey("VIDEO1", CompositeInput_Key, 0x23, 8);
+  addKey("VIDEO2", Composite2Input_Key, 0x24, 8);
+  addKey("VIDEO3", SVideoInput_Key, 0x25, 8); // bit of a hack
   addKey("TAPE_MD_CDR", TapeInput_Key, 0x26, 8);
   addKey("CD_AUX", AuxInput_Key, 0x27, 8);
 
@@ -200,6 +201,21 @@ void CambridgeAudio2::populateProtocol(
 }
 
 
+void CambridgeAudio2::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("AM / FM Toggle", QVariant(TunerInput_Key));
+  cb->addItem("DVD", QVariant(DVDInput_Key));
+  cb->addItem("Video 1", QVariant(CompositeInput_Key));
+  cb->addItem("Video 2", QVariant(Composite2Input_Key));
+  cb->addItem("Video 3", QVariant(SVideoInput_Key));
+  cb->addItem("Tape / MD / CDR", QVariant(TapeInput_Key));
+  cb->addItem("CD / Aux", QVariant(AuxInput_Key));
+}
+
+
 CambridgeAudio3::CambridgeAudio3(
   unsigned int index)
   : PIRKeysetMetaData(
@@ -243,6 +259,20 @@ void CambridgeAudio3::populateProtocol(
 }
 
 
+void CambridgeAudio3::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("CD", QVariant(CDInput_Key));
+  cb->addItem("DVD", QVariant(DVDInput_Key));
+  cb->addItem("Tuner / DAB", QVariant(TunerInput_Key));
+  cb->addItem("Tape Monitor", QVariant(TapeInput_Key));
+  cb->addItem("AV / MD", QVariant(MDInput_Key));
+  cb->addItem("Aux / Phono", QVariant(AuxInput_Key));
+}
+
+
 CambridgeDVD1::CambridgeDVD1(
   unsigned int index)
   : PIRKeysetMetaData(
