@@ -22,6 +22,7 @@
 
 #include "epson.h"
 #include "protocols/necprotocol.h"
+#include <QComboBox>
 
 EpsonProjector1::EpsonProjector1(
   unsigned int index)
@@ -131,6 +132,21 @@ void EpsonProjector1::populateProtocol(
 }
 
 
+void EpsonProjector1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("Video", QVariant(AuxInput_Key));
+  cb->addItem("Input A / Component", QVariant(ComponentInput_Key));
+  cb->addItem("D / SCART", QVariant(ScartInput_Key));
+  cb->addItem("HDMI", QVariant(HDMIInput_Key));
+  cb->addItem("USB Display", QVariant(USBInput_Key));
+  cb->addItem("Video 2", QVariant(SVideoInput_Key));
+  cb->addItem("Input A-B", QVariant(Input_Key));
+}
+
+
 EpsonProjector1a::EpsonProjector1a(
   unsigned int index)
   : EpsonProjector1(index)
