@@ -22,6 +22,7 @@
 
 #include "kaon.h"
 #include "protocols/necprotocol.h"
+#include <QComboBox>
 
 
 KaonSat1::KaonSat1(
@@ -88,3 +89,13 @@ void KaonSat1::populateProtocol(
   addKey("9", Nine_Key, 0x46, 8);
   addKey("0", Zero_Key, 0x47, 8);
 }
+
+
+void KaonSat1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV - Radio", QVariant(TunerInput_Key));
+  cb->addItem("TV - STB", QVariant(Input_Key));
+}
