@@ -30,6 +30,7 @@
 #include <QThread>
 
 class QObject;
+class QComboBox;
 class PIRSelectKeysetForm;
 class PIRSelectDeviceForm;
 class PIRFavoritesDialog;
@@ -56,6 +57,10 @@ public:
     PIRSelectKeysetForm *skf,
     PIRFavoritesDialog *fd) const;
 
+  void populateInputList(
+    QComboBox *cb,
+    unsigned int keysetID) const;
+
   bool keysetExists(
     unsigned int keysetID) const;
 
