@@ -49,7 +49,7 @@ class PIRPlaystationForm;
 class PIRUserForm;
 
 // These need to go elsewhere:
-class PIRMacroForm;
+//class PIRMacroForm;
 //class PIRPowerSearchForm;
 //class PIRAdvancedForm;
 
@@ -96,6 +96,8 @@ public:
   void useMainPanel();
   void useAltMainPanel();
 
+  void setupMacroForm();
+
 /*
   void setupUniversalTabs();
   void setupTVTabs();
@@ -104,7 +106,7 @@ public:
   void setupRecordTabs();
 */
 
-  QComboBox *getKeysetComboBox();
+//  QComboBox *getKeysetComboBox();
 
 //  void gotoPreviousTabs();
 //  void gotoNextTabs();
@@ -136,7 +138,7 @@ private:
   PIRRoombaForm *roombaForm;
   PIRPlaystationForm *playstationForm;
   PIRUserForm *userForm;
-  PIRMacroForm *macroForm;
+//  PIRMacroForm *macroForm;
 //  PIRPowerSearchForm *powerSearchForm;
 //  PIRAdvancedForm *advancedForm;
 
